.. sync_or_swim

Welcome to sync_or_swim's documentation!
========================================

Sync your data files across all of your machines (tinyurl.com/sync-or-swim)

.. toctree::
   :maxdepth: -1
   :caption: Table of Contents

    API Reference <modules>
    Changelog <changelog>
    Development Guide <contributing>
    README <readme>


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
